=========
Changelog
=========

In the unlikely event that I remember to update this file here is
an attempt to keep track of progress.




2021-12-17
==========
Added a working example in ImageD11/project/h5demo1.py which is
building a virtual dataset and a series of external links to find
frames in external edf files.



